summaryrefslogtreecommitdiff
path: root/sw/inc/undobj.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/undobj.hxx')
-rw-r--r--sw/inc/undobj.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sw/inc/undobj.hxx b/sw/inc/undobj.hxx
index 9944cfbd5c..654fd2e794 100644
--- a/sw/inc/undobj.hxx
+++ b/sw/inc/undobj.hxx
@@ -69,7 +69,7 @@ protected:
void RemoveIdxFromRange( SwPaM& rPam, sal_Bool bMoveNext );
void RemoveIdxRel( sal_uLong, const SwPosition& );
- static BOOL CanRedlineGroup( SwRedlineSaveDatas& rCurr,
+ static sal_Bool CanRedlineGroup( SwRedlineSaveDatas& rCurr,
const SwRedlineSaveDatas& rCheck,
sal_Bool bCurrIsEnd );
@@ -81,7 +81,7 @@ protected:
*/
virtual SwRewriter GetRewriter() const;
// return type is USHORT because this overrides SfxUndoAction::GetId()
virtual sal_uInt16 GetId() const { return static_cast<sal_uInt16>(m_nId); }
// the 4 methods that derived classes have to override
@@ -99,7 +99,7 @@ private:
virtual void UndoWithContext(SfxUndoContext &);
virtual void RedoWithContext(SfxUndoContext &);
virtual void Repeat(SfxRepeatTarget &);
- virtual BOOL CanRepeat(SfxRepeatTarget &) const;
+ virtual sal_Bool CanRepeat(SfxRepeatTarget &) const;
public:
SwUndo(SwUndoId const nId);
@@ -81,7 +81,7 @@ protected:
*/
virtual SwRewriter GetRewriter() const;
- // return type is USHORT because this overrides SfxUndoAction::GetId()
+ // return type is sal_uInt16 because this overrides SfxUndoAction::GetId()
virtual sal_uInt16 GetId() const { return static_cast<sal_uInt16>(m_nId); }
// the 4 methods that derived classes have to override